==> atlassian_connect_host-0.5.6.tar.gz: test/host_service/host_http_client_test.dart <==
library ac_dart.host_http_client.test;

import 'dart:async';
import 'dart:io';

import 'package:atlassian_connect_host/src/host_service/host_http_client.dart';
import 'package:atlassian_connect_jwt/atlassian_connect_jwt.dart';
import 'package:mockito/mockito.dart';
import 'package:option/option.dart';
import 'package:quiver/collection.dart';
import 'package:test/test.dart';

class _MockHttpClient extends Mock implements HttpClient {
}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {
}

class _MockHttpHeaders extends Mock implements HttpHeaders {
}
//
//class _MockHttpClientResponse extends Mock implements HttpClientResponse {
//  noSuchMethod(i) => super.noSuchMethod(i);
//}

main() {
  group('[jwt]', () {
    _MockHttpClient _httpClient;
    _MockHttpClientRequest _httpClientRequest;
    _MockHttpHeaders headers;

    setUp(() {
      _httpClient = new _MockHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      headers = new _MockHttpHeaders();
      when(_httpClientRequest.headers).thenReturn(headers);
      when(_httpClient.openUrl(any, any))
          .thenReturn(new Future.value(_httpClientRequest));
    });

    final Uri httpBaseUri = Uri.parse('http://localhost:8888/blah');
    const String sharedSecret = "shhh it's a secret";
    const String issuer = "da host";
    const String audience = "da aud";

    void _checkJwt(bool signRequest, Matcher jwtMatcher) {
      final AcHostHttpClient client = new AcHostHttpClient(
          httpBaseUri,
          new Some(sharedSecret),
          new Some(issuer),
          _httpClient,
          new Some(audience), false);
      Future<HttpClientRequest> futureRequest = client.get('/apath',
          signRequest: signRequest, queryParams: {'foo': '12'});
      futureRequest.then((req) {
        verify(_httpClient.openUrl(
                "GET", argThat(new HasUriWithJwtThat(jwtMatcher))))
            .called(1);
      });
      expect(futureRequest, completes);
    }

    test("doesn't add jwt when signRequest = false", () {
      _checkJwt(false, isNull);
    });

    test("does add jwt when signRequest = true", () {
      _checkJwt(true, isNotNull);
    });

    test("jwt has expected issuer", () {
      _checkJwt(
          true,
          new HasClaimThat((ProductHostClaimSet claimSet) => claimSet.issuer,
              equals(issuer)));
    });

    test("jwt has expected audience", () {
      _checkJwt(
          true,
          new HasClaimThat((ProductHostClaimSet claimSet) => claimSet.audience,
              unorderedEquals([audience])));
    });

    test("jwt has issuedAt = now", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.issuedAt,
              predicate((DateTime issuedAt) =>
                  issuedAt.difference(new DateTime.now()) <
                  const Duration(milliseconds: 3))));
    });

    test("jwt has expiry in future", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.expiry,
              predicate(
                  (DateTime expiry) => expiry.isAfter(new DateTime.now()))));
    });

    test("jwt has no subject", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.subject, isNull));
    });

    test("jwt has expected qsh", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.queryStringHash,
              equals(createQshFromPath(
                  '/apath', 'GET', new Multimap()..add('foo', '12')))));
    });
  });
}

class HasUriWithJwtThat extends CustomMatcher {
  HasUriWithJwtThat(matcher)
      : super("Uri with jwt query parameter that is", "jwt", matcher);

  featureValueOf(actualUri) => actualUri.queryParameters['jwt'];

  bool matches(item, Map matchState) {
    final bool _matches = super.matches(item, matchState);
    if (!_matches) {
      print(
          'actual is $item'); // TODO: not sure how to get some feedback on the verify
//      matchState['actual uri was'] = item;
    }
    return _matches;
  }
}

typedef dynamic Claim(ProductHostClaimSet cs);

class HasClaimThat extends CustomMatcher {
  final Claim claim;
  HasClaimThat(this.claim, matcher)
      : super("Has Jwt Claim that is", "claim", matcher);

  featureValueOf(jwtToken) => claim(decodeProductHostToken(jwtToken).claimSet);

  bool matches(item, Map matchState) {
    final bool _matches = super.matches(item, matchState);
    if (!_matches) {
//    TODO: not sure how to get some feedback on the verify
      print('jwtToken is $item.\nclaim is ${featureValueOf(item)}');
//      matchState['actual uri was'] = item;
    }
    return _matches;
  }
}

==> atlassian_connect_host-0.5.7.tar.gz: test/host_service/host_http_client_test.dart <==
library ac_dart.host_http_client.test;

import 'dart:async';
import 'dart:io';

import 'package:atlassian_connect_host/src/host_service/host_http_client.dart';
import 'package:atlassian_connect_jwt/atlassian_connect_jwt.dart';
import 'package:mockito/mockito.dart';
import 'package:option/option.dart';
import 'package:quiver/collection.dart';
import 'package:test/test.dart';

class _MockHttpClient extends Mock implements HttpClient {}

class _MockHttpClientRequest extends Mock implements HttpClientRequest {}

class _MockHttpHeaders extends Mock implements HttpHeaders {}
//
//class _MockHttpClientResponse extends Mock implements HttpClientResponse {
//  noSuchMethod(i) => super.noSuchMethod(i);
//}

main() {
  group('[jwt]', () {
    _MockHttpClient _httpClient;
    _MockHttpClientRequest _httpClientRequest;
    _MockHttpHeaders headers;

    setUp(() {
      _httpClient = new _MockHttpClient();
      _httpClientRequest = new _MockHttpClientRequest();
      headers = new _MockHttpHeaders();
      when(_httpClientRequest.headers).thenReturn(headers);
      when(_httpClient.openUrl(any, any))
          .thenReturn(new Future.value(_httpClientRequest));
    });

    final Uri httpBaseUri = Uri.parse('http://localhost:8888/blah');
    const String sharedSecret = "shhh it's a secret";
    const String issuer = "da host";
    const String audience = "da aud";

    void _checkJwt(bool signRequest, Matcher jwtMatcher) {
      final AcHostHttpClient client = new AcHostHttpClient(
          httpBaseUri,
          new Some(sharedSecret),
          new Some(issuer),
          _httpClient,
          new Some(audience),
          false);
      Future<HttpClientRequest> futureRequest = client
          .get('/apath', signRequest: signRequest, queryParams: {'foo': '12'});
      futureRequest.then((req) {
        verify(_httpClient.openUrl(
                "GET", argThat(new HasUriWithJwtThat(jwtMatcher))))
            .called(1);
      });
      expect(futureRequest, completes);
    }

    test("doesn't add jwt when signRequest = false", () {
      _checkJwt(false, isNull);
    });

    test("does add jwt when signRequest = true", () {
      _checkJwt(true, isNotNull);
    });

    test("jwt has expected issuer", () {
      _checkJwt(
          true,
          new HasClaimThat((ProductHostClaimSet claimSet) => claimSet.issuer,
              equals(issuer)));
    });

    test("jwt has expected audience", () {
      _checkJwt(
          true,
          new HasClaimThat((ProductHostClaimSet claimSet) => claimSet.audience,
              unorderedEquals([audience])));
    });

    test("jwt has issuedAt = now", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.issuedAt,
              predicate((DateTime issuedAt) =>
                  issuedAt.difference(new DateTime.now()) <
                  const Duration(milliseconds: 3))));
    });

    test("jwt has expiry in future", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.expiry,
              predicate(
                  (DateTime expiry) => expiry.isAfter(new DateTime.now()))));
    });

    test("jwt has no subject", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.subject, isNull));
    });

    test("jwt has expected qsh", () {
      _checkJwt(
          true,
          new HasClaimThat(
              (ProductHostClaimSet claimSet) => claimSet.queryStringHash,
              equals(createQshFromPath(
                  '/apath', 'GET', new Multimap()..add('foo', '12')))));
    });
  });
}

class HasUriWithJwtThat extends CustomMatcher {
  HasUriWithJwtThat(matcher)
      : super("Uri with jwt query parameter that is", "jwt", matcher);

  featureValueOf(actualUri) => actualUri.queryParameters['jwt'];

  bool matches(item, Map matchState) {
    final bool _matches = super.matches(item, matchState);
    if (!_matches) {
      print(
          'actual is $item'); // TODO: not sure how to get some feedback on the verify
//      matchState['actual uri was'] = item;
    }
    return _matches;
  }
}

typedef dynamic Claim(ProductHostClaimSet cs);

class HasClaimThat extends CustomMatcher {
  final Claim claim;
  HasClaimThat(this.claim, matcher)
      : super("Has Jwt Claim that is", "claim", matcher);

  featureValueOf(jwtToken) => claim(decodeProductHostToken(jwtToken).claimSet);

  bool matches(item, Map matchState) {
    final bool _matches = super.matches(item, matchState);
    if (!_matches) {
//    TODO: not sure how to get some feedback on the verify
      print('jwtToken is $item.\nclaim is ${featureValueOf(item)}');
//      matchState['actual uri was'] = item;
    }
    return _matches;
  }
}
